class hilight:
    """
        class hilight(string).color(highlight=True, bold=True)

        EXAMPLE:
            print (hilight("Hello World").red(bold=True))

            Or you could make an object:
                text = hilight("Bar")

                print ("Foo "+text.blue())

            To return the original string:
                print (text.string)
        
        COLORS:
            red
            green
            yellow
            blue
            purple
            teal
            white
    """
    def __init__(self, string):
        self.string = string


    def red(self, bold=False, highlight=False):
        """ hilight(string).red(bold=False, highlight=False) """
        attr = []

        if highlight:
            attr.append('41')
        else:
            attr.append('31')

        if bold:
            attr.append('1')

        return '\x1b[%sm%s\x1b[0m' % (';'.join(attr), self.string)


    def green(self, bold=False, highlight=False):
        """ hilight(string).green(bold=False, highlight=False) """
        attr = []

        if highlight:
            attr.append('42')
        else:
            attr.append('32')

        if bold:
            attr.append('1')

        return '\x1b[%sm%s\x1b[0m' % (';'.join(attr), self.string)


    def yellow(self, bold=False, highlight=False):
        """ hilight(string).yellow(bold=False, highlight=False) """
        attr = []

        if highlight:
            attr.append('43')
        else:
            attr.append('33')

        if bold:
            attr.append('1')

        return '\x1b[%sm%s\x1b[0m' % (';'.join(attr), self.string)


    def blue(self, bold=False, highlight=False):
        """ hilight(string).blue(bold=False, highlight=False) """
        attr = []

        if highlight:
            attr.append('44')
        else:
            attr.append('34')

        if bold:
            attr.append('1')

        return '\x1b[%sm%s\x1b[0m' % (';'.join(attr), self.string)


    def purple(self, bold=False, highlight=False):
        """ hilight(string).purple(bold=False, highlight=False) """
        attr = []

        if highlight:
            attr.append('45')
        else:
            attr.append('35')

        if bold:
            attr.append('1')

        return '\x1b[%sm%s\x1b[0m' % (';'.join(attr), self.string)


    def teal(self, bold=False, highlight=False):
        """ hilight(string).teal(bold=False, highlight=False) """
        attr = []

        if highlight:
            attr.append('46')
        else:
            attr.append('36')

        if bold:
            attr.append('1')

        return '\x1b[%sm%s\x1b[0m' % (';'.join(attr), self.string)


    def white(self, bold=False, highlight=False):
        """ hilight(string).white(bold=False, highlight=False) """
        attr = []

        if highlight:
            attr.append('47')
        else:
            attr.append('37')

        if bold:
            attr.append('1')

        return '\x1b[%sm%s\x1b[0m' % (';'.join(attr), self.string)




"""
        Module to convert various data

        11/07/2016 - Created
		02/03/2019 - Converted to make python3 compatible 
        
        def convert_time_from_seconds(seconds_given)
			Converts seconds into minutes/hours. 
		
		def IP2Int(ip)
			Converts an IPv4 address to a interger - This is useful to store IP addresses in databases
		
		def Int2IP(ipnum)
			Converts an interger back to an IPv4 address

		def urlcode(url, encode=False)
			Wrapper for urllib.parse.quote and urllib.parse.unquote.
			From urllib docs - Replace special characters in string using the %xx escape. Letters, digits, 
			and the characters '_.-' are never quoted. By default, this function is intended for quoting 
			the path section of URL. 
			https://docs.python.org/3.1/library/urllib.parse.html?highlight=urllib#urllib.parse.quote

"""
import urllib.parse

version = '1.1'

def convert_time_from_seconds(seconds_given):
	if seconds_given == "N/A":
		return seconds_given
	else:
		m, s = divmod(seconds_given, 60)
		h, m = divmod(m, 60)
		total_time = "%d:%02d:%02d" % (h, m, s)

		return total_time


def IP2Int(ip):
	if '.' in str(ip):
		o = list(map(int, ip.split('.')))
		res = (16777216 * o[0]) + (65536 * o[1]) + (256 * o[2]) + o[3]
		return res
	else:
		return ip


def Int2IP(ipnum):
	o1 = int(ipnum / 16777216) % 256
	o2 = int(ipnum / 65536) % 256
	o3 = int(ipnum / 256) % 256
	o4 = int(ipnum) % 256
	return '%(o1)s.%(o2)s.%(o3)s.%(o4)s' % locals()


def urlcode(url, encode=False):
	if encode:
		# Convert string to URL safe
		return urllib.parse.quote(url)
	else:
		# Convert string to human readable
		return urllib.parse.unquote(url)



import sys

# update_progress() : Displays or updates a console progress bar
## Accepts a float between 0 and 1. Any int will be converted to a float.
## A value under 0 represents a 'halt'.
## A value at 1 or bigger represents 100%
def progress_bar(progress, barLength=50, text_field="Progress"):
    status = ""
    if isinstance(progress, int):
        progress = float(progress)
    if not isinstance(progress, float):
        progress = 0
        status = "error: progress var must be float\r\n"
    if progress < 0:
        progress = 0
        status = "Halt...\r\n"
    if progress >= 1:
        progress = 1
        status = "Done...\r\n"
    block = int(round(barLength*progress))
    text = "\r		{3}: [{0}] {1}% {2}".format( "#"*block + "-"*(barLength-block), progress*100, status, text_field)
    print(text, end='\r')
    #sys.stdout.write(text)
    #sys.stdout.flush()
